#ifndef _RVF_FORMAT_H
#define _RVF_FORMAT_H


#define HEADER_MAGIC 0x52564668 // "RVFh" at file start 
#define AUDIO_MAGIC  0x41756446 // "AudF" for each audio block
#define FILEVERSION  100 // 1.00
#define CLOCK 11059200 // SH CPU clock

// format type definitions
#define VIDEOFORMAT_NO_VIDEO       0
#define VIDEOFORMAT_RAW            1
#define AUDIOFORMAT_NO_AUDIO       0
#define AUDIOFORMAT_MP3            1
#define AUDIOFORMAT_MP3_BITSWAPPED 2

// bit flags
#define FLAG_LOOP 0x00000001 // loop the playback, e.g. for stills

#ifdef WIN32
#pragma pack(push, before_rvf_structs) // save the struct alignment
#pragma pack(1) // do not pad my structures
#endif

typedef struct // contains whatever might be useful to the player
{
    // general info (16 entries = 64 byte)
    unsigned long magic; // HEADER_MAGIC
    unsigned long version; // file version
    unsigned long flags; // combination of FLAG_xx
    unsigned long blocksize; // how many bytes per block (=video frame)
    unsigned long bps_average; // bits per second of the whole stream
    unsigned long bps_peak; // max. of above (audio may be VBR)
    unsigned long resume_pos; // file position to resume to (bookmark)
    unsigned long reserved[9]; // reserved, should be zero

    // video info (16 entries = 64 byte)
    unsigned long video_format; // one of VIDEOFORMAT_xxx
    unsigned long video_1st_frame; // byte position of first video frame
    unsigned long video_duration; // total length of video part, in ms
    unsigned long video_payload_size; // total amount of video data, in bytes
    unsigned long video_bitrate; // derived from resolution and frame time, in bps
    unsigned long video_frametime; // frame interval in 11.0592 MHz clocks
    long video_preroll; // video is how much ahead, in 11.0592 MHz clocks
    unsigned long video_width; // in pixels
    unsigned long video_height; // in pixels
    unsigned long video_reserved[7]; // reserved, should be zero

    // audio info (16 entries = 64 byte)
    unsigned long audio_format; // one of AUDIOFORMAT_xxx
    unsigned long audio_1st_frame; // byte position of first video frame
    unsigned long audio_duration; // total length of audio part, in ms
    unsigned long audio_payload_size; // total amount of audio data, in bytes
    unsigned long audio_avg_bitrate; // average audio bitrate, in bits per second
    unsigned long audio_peak_bitrate; // maximum bitrate
    unsigned long audio_headersize; // offset to payload in audio frames
    long audio_min_associated; // minimum offset to video frame, in bytes
    long audio_max_associated; // maximum offset to video frame, in bytes
    unsigned long audio_reserved[7]; // reserved, should be zero

   // more to come... ?

    // Note: padding up to 'blocksize' with zero following this header
} tFileHeader;

typedef struct // the little header for all audio blocks
{
    unsigned long magic; // AUDIO_MAGIC indicates an audio block
	unsigned char previous_block; // previous how many blocks backwards
    unsigned char next_block; // next how many blocks forward
	short associated_video; // offset to block with corresponding video
    unsigned short frame_start; // offset to first frame starting in this block
    unsigned short frame_end; // offset to behind last frame ending in this block
	// Audio data follows after this, up to the block end.
} tAudioFrameHeader;

#ifdef WIN32
#pragma pack(pop, before_rvf_structs) // return to default alignment
#endif

#endif // #ifndef _RVF_FORMAT_H

